@@ -7,7 +7,9 @@ data Config = Config {cCtrlListen :: Bool,
                       cFrameTimespan :: Double,
                       cTempoAddr :: String,
                       cTempoPort :: Int,
-                      cTempoClientPort :: Int
+                      cTempoClientPort :: Int,
+                      cSendParts :: Bool,
+                      cSkipTicks :: Int
                      }
 
 defaultConfig :: Config
@@ -17,5 +19,7 @@ defaultConfig = Config {cCtrlListen = True,
                         cFrameTimespan = 1/20,
                         cTempoAddr = "127.0.0.1",
                         cTempoPort = 9160,
-                        cTempoClientPort = 0 -- choose at random
+                        cTempoClientPort = 0, -- choose at random
+                        cSendParts = False,
+                        cSkipTicks = 10
                        }
