@@ -3,7 +3,6 @@
 import Test.Microspec
 
 import Sound.Tidal.CoreTest
-import Sound.Tidal.MiniTidalTest
 import Sound.Tidal.ParseTest
 import Sound.Tidal.PatternTest
 import Sound.Tidal.ControlTest
@@ -14,7 +13,6 @@ import Sound.Tidal.UtilsTest
 main :: IO ()
 main = microspec $ do
   Sound.Tidal.CoreTest.run
-  Sound.Tidal.MiniTidalTest.run
   Sound.Tidal.ParseTest.run
   Sound.Tidal.PatternTest.run
   Sound.Tidal.ControlTest.run
